@@ -33,18 +33,20 @@ QDataStream &operator<<(QDataStream &out, const Player &player)
 {
     out << player.BaseCombatSkill << player.BaseEndurance
         << player.Endurance << player.GoldCrowns << player.HasBackpack() << player.DeathsCount << player.TemporaryCombatSkillDelta
-        << player.Properties;
+        << player.Properties << player.CanHunt();
     return out;
 }
 
 QDataStream &operator>>(QDataStream &in, Player &player)
 {
     bool backpack = true;
+    bool canHunt  = true;
     in >> player.BaseCombatSkill >> player.BaseEndurance
        >> player.Endurance >> player.GoldCrowns >> backpack >> player.DeathsCount >> player.TemporaryCombatSkillDelta
-       >> player.Properties;
+       >> player.Properties >> canHunt;
 
     player.SetHasBackpack(backpack);
+    player.SetCanHunt(canHunt);
 
     return in;
 }
@@ -225,6 +227,7 @@ BookWindow::BookWindow(QWidget *parent) :
 
     m_Section = NULL;
     m_Book = NULL;
+    m_Player = NULL;
 
     m_Loaded = false;
 
@@ -837,6 +840,10 @@ bool BookWindow::Load(QString filename)
 
     m_Section = NULL;
     int bookNumber = settings.value("book").toInt();
+    if (m_Book != NULL){
+        delete m_Book;
+        m_Book = NULL;
+    }
     m_Book = new Book(this);
     if (!m_Book->Load(Books::GetBookFilename(bookNumber))){
         QMessageBox msgBox(this);
@@ -846,6 +853,7 @@ bool BookWindow::Load(QString filename)
         msgBox.setText(QString("Error loading book:\n%1").arg(Books::GetBookFilename(bookNumber)));
         msgBox.exec();
 
+        delete m_Book;
         m_Book = NULL;
         return false;
     }else{
@@ -854,11 +862,15 @@ bool BookWindow::Load(QString filename)
         m_Section = m_Book->Sections[sectionNumber];
     }
 
-    QVariant var = settings.value("player");
-    if (var.isValid()){
-        m_Player = new Player(var.value<Player>());
+    if (m_Player != NULL){
+        delete m_Player;
+        m_Player = NULL;
     }
 
+    QVariant var = settings.value("player");
+    if (var.isValid())
+        m_Player = new Player(var.value<Player>());
+
     int index = settings.beginReadArray("items");
     for (int i=0; i<index; i++){
         settings.setArrayIndex(i);
