@@ -9,6 +9,7 @@ Player::Player(QObject *parent) :
     Endurance = 0;
     GoldCrowns = 0;
     KaiDisciplines.clear();
+
     m_Backpack = true;
     m_CanHunt = true;
 
@@ -18,18 +19,16 @@ Player::Player(QObject *parent) :
 Player::Player(const Player& player) :
         QObject(player.parent())
 {
-    TemporaryCombatSkillDelta = 0;
+    TemporaryCombatSkillDelta = player.TemporaryCombatSkillDelta;
     BaseCombatSkill = player.BaseCombatSkill;
     BaseEndurance = player.BaseEndurance;
     Endurance = player.Endurance;
     GoldCrowns = player.GoldCrowns;
 
     m_Backpack = player.m_Backpack;
+    m_CanHunt = player.m_CanHunt;
 
-    /*QList<KaiDiscipline*> KaiDisciplines;
-    QList<Weapon*> Weapons;
-    QList<Item*> Items;
-    */
+    DeathsCount = player.DeathsCount;
 }
 
 QList<Weapon*> Player::Weapons()
